<h1 align = "center">
	Visual-Crossing Weather API <img src = "./assets/logo.png" height = "190" width = "175" align = "right" /><br>
	<a href = "https://www.linkedin.com/in/dpramanik/"><img height="16" width="16" src="https://unpkg.com/simple-icons@v3/icons/linkedin.svg"/></a>
	<a href = "https://github.com/ZenithClown"><img height="16" width="16" src="https://unpkg.com/simple-icons@v3/icons/github.svg"/></a>
	<a href = "https://gitlab.com/ZenithClown/"><img height="16" width="16" src="https://unpkg.com/simple-icons@v3/icons/gitlab.svg"/></a>
	<a href = "https://www.researchgate.net/profile/Debmalya_Pramanik2"><img height="16" width="16" src="https://unpkg.com/simple-icons@v3/icons/researchgate.svg"/></a>
	<a href = "https://www.kaggle.com/dPramanik/"><img height="16" width="16" src="https://unpkg.com/simple-icons@v3/icons/kaggle.svg"/></a>
	<a href = "https://app.pluralsight.com/profile/Debmalya-Pramanik/"><img height="16" width="16" src="https://unpkg.com/simple-icons@v3/icons/pluralsight.svg"/></a>
	<a href = "https://stackoverflow.com/users/6623589/"><img height="16" width="16" src="https://unpkg.com/simple-icons@v3/icons/stackoverflow.svg"/></a>
</h1>

<p align = "justify">In collaboration with <a href = "https://www.visualcrossing.com/weather-data">VisualCrossing</a> as a Weather Ambassador, I am creating a <i>python wrapper</i> that can be used by any entusiast to fetch the latest data. The Visual Crossing Weather API provides developers with weather data for any programming language or script. The Weather API provides instant and scalable access to both historical weather reports and forecast data in an easy-to-use JSON or text format.</p>

<p align = "justify"><a href = "https://www.visualcrossing.com/">VisualCrossing</a> also provides free access to weather data. In <b>free version</b> you are allowed to fetch <b>1000 records/day</b> and the limit can be increased further by doing some fun activities like writing a blog post or sharing the news in social media! Create a free account from <a href = "https://www.visualcrossing.com/weather/weather-data-services">https://www.visualcrossing.com/weather/weather-data-services</a> and using the API key, and start by <code>pip install VisualCrossing</code>.</p>

<p align = "justify"><b>NOTE:</b> the product is currently in <b><code>Development Status :: 4 - Beta</code></b>, and much changes are to come and developed. Your opinions, feedback, and enhancement is much appreciated!</p>
